@@ -49,35 +49,54 @@ class InternalBackendConf(SharedBackendConfUtils):
     def spreadRddRetriesTimeout(self):
         return self._jconf.spreadRddRetriesTimeout()
 
+    def isDirectIpConfigurationEnabled(self):
+        return self._jconf.isDirectIpConfigurationEnabled()
+
 
     #
     # Setters
     #
 
-    def setNumH2OWorkers(self, value):
-        self._jconf.setNumH2OWorkers(value)
+    def setNumH2OWorkers(self, arg0):
+        self._jconf.setNumH2OWorkers(arg0)
         return self
 
-    def setDrddMulFactor(self, value):
-        self._jconf.setDrddMulFactor(value)
+    def setExtraClusterNodesEnabled(self):
+        self._jconf.setExtraClusterNodesEnabled()
         return self
 
-    def setNumRddRetries(self, value):
-        self._jconf.setNumRddRetries(value)
+    def setExtraClusterNodesDisabled(self):
+        self._jconf.setExtraClusterNodesDisabled()
         return self
 
-    def setDefaultCloudSize(self, value):
-        self._jconf.setDefaultCloudSize(value)
+    def setDrddMulFactor(self, arg0):
+        self._jconf.setDrddMulFactor(arg0)
         return self
 
-    def setSubseqTries(self, value):
-        self._jconf.setSubseqTries(value)
+    def setNumRddRetries(self, arg0):
+        self._jconf.setNumRddRetries(arg0)
         return self
 
-    def setHdfsConf(self, value):
-        self._jconf.setHdfsConf(value)
+    def setDefaultCloudSize(self, arg0):
+        self._jconf.setDefaultCloudSize(arg0)
         return self
 
-    def setSpreadRddRetriesTimeout(self, value):
-        self._jconf.setSpreadRddRetriesTimeout(value)
+    def setSubseqTries(self, arg0):
+        self._jconf.setSubseqTries(arg0)
+        return self
+
+    def setHdfsConf(self, *args):
+        self._jconf.setHdfsConf(*args)
+        return self
+
+    def setSpreadRddRetriesTimeout(self, arg0):
+        self._jconf.setSpreadRddRetriesTimeout(arg0)
+        return self
+
+    def setDirectIpConfigurationEnabled(self):
+        self._jconf.setDirectIpConfigurationEnabled()
+        return self
+
+    def setDirectIpConfigurationDisabled(self):
+        self._jconf.setDirectIpConfigurationDisabled()
         return self
