@@ -25,9 +25,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
-    def isH2OReplEnabled(self):
-        return self._jconf.isH2OReplEnabled()
-
     def cloudName(self):
         return self._get_option(self._jconf.cloudName())
 
@@ -73,6 +70,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def kerberosLogin(self):
         return self._jconf.kerberosLogin()
 
+    def pamLogin(self):
+        return self._jconf.pamLogin()
+
     def loginConf(self):
         return self._get_option(self._jconf.loginConf())
 
@@ -199,6 +199,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def restApiTimeout(self):
         return self._jconf.restApiTimeout()
 
+    def isH2OReplEnabled(self):
+        return self._jconf.isH2OReplEnabled()
+
     def nthreads(self):
         return self._jconf.nthreads()
 
@@ -315,6 +318,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
+    def setPamLoginEnabled(self):
+        self._jconf.setPamLoginEnabled()
+        return self
+
+    def setPamLoginDisabled(self):
+        self._jconf.setPamLoginDisabled()
+        return self
+
     def setLoginConf(self, arg0):
         self._jconf.setLoginConf(arg0)
         return self
@@ -347,14 +358,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setLogDir(arg0)
         return self
 
-    def setBackendHeartbeatInterval(self, arg0):
-        self._jconf.setBackendHeartbeatInterval(arg0)
-        return self
-
     def setCloudTimeout(self, arg0):
         self._jconf.setCloudTimeout(arg0)
         return self
 
+    def setBackendHeartbeatInterval(self, arg0):
+        self._jconf.setBackendHeartbeatInterval(arg0)
+        return self
+
     def setNodeNetworkMask(self, arg0):
         self._jconf.setNodeNetworkMask(arg0)
         return self
