@@ -17,9 +17,11 @@
 
 from ai.h2o.sparkling.ml.params.H2OMOJOModelParams import H2OTreeBasedSupervisedMOJOModelParams
 from pyspark.ml.util import _jvm
+from py4j.java_gateway import JavaObject
 from ai.h2o.sparkling.Initializer import Initializer
 from ai.h2o.sparkling.ml.models.H2OMOJOSettings import H2OMOJOSettings
 from ai.h2o.sparkling.ml.params.H2OTypeConverters import H2OTypeConverters
+from ai.h2o.sparkling.H2ODataFrameConverters import H2ODataFrameConverters
 from ai.h2o.sparkling.ml.params.HasIgnoredColsOnMOJO import HasIgnoredColsOnMOJO
 
 
@@ -32,6 +34,17 @@ class H2ODRFMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         javaModel = _jvm().ai.h2o.sparkling.ml.models.H2ODRFMOJOModel.createFromMojo(pathToMojo, settings.toJavaObject())
         return H2ODRFMOJOModel(javaModel)
 
+
+    def getCrossValidationModels(self):
+        cvModels = self._java_obj.getCrossValidationModelsAsArray()
+        if cvModels is None:
+            return None
+        elif isinstance(cvModels, JavaObject):
+            return [H2ODRFMOJOModel(v) for v in cvModels]
+        else:
+            raise TypeError("Invalid type.")
+
+
     def getMtries(self):
         value = self._java_obj.getMtries()
         return value
@@ -137,6 +150,11 @@ class H2ODRFMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
         return value
 
 
+    def getCalibrationMethod(self):
+        value = self._java_obj.getCalibrationMethod()
+        return value
+
+
     def getCheckConstantResponse(self):
         value = self._java_obj.getCheckConstantResponse()
         return value
@@ -240,3 +258,6 @@ class H2ODRFMOJOModel(H2OTreeBasedSupervisedMOJOModelParams, HasIgnoredColsOnMOJ
     def getAucType(self):
         value = self._java_obj.getAucType()
         return value
+
+    # Outputs
+
